/*
 * share/stropts.h
 */


#ifndef share_stropts_h
#define share_stropts_h


#ifndef ASM_FILE


enum{
	/* ioctlѥޥɡ */
	IOCTL_COM_TCGETTCATTR=0,
	IOCTL_COM_TCSETTCATTR,
	IOCTL_COM_TCSENDBREAK,
	IOCTL_COM_TCDRAIN,
	IOCTL_COM_TCFLASH,
	IOCTL_COM_TCFLOW,
	
	TIOCSCTTY,			/* üꡣ */
	TIOSPGRP,			/* üץ롼פѹ */
	TIOGPGRP,			/* üץ롼פμ */
};


#endif


#endif
